@@ -77,11 +77,18 @@ module Facter::Util::IP
   def self.get_all_interface_output
     case Facter.value(:kernel)
     when 'Linux', 'OpenBSD', 'NetBSD', 'FreeBSD', 'Darwin', 'GNU/kFreeBSD', 'DragonFly'
-      output = %x{/sbin/ifconfig -a 2>/dev/null}
+      output = Facter::Util::IP.exec_ifconfig(["-a","2>/dev/null"])
     when 'SunOS'
-      output = %x{/usr/sbin/ifconfig -a}
+      output = Facter::Util::IP.exec_ifconfig(["-a"])
     when 'HP-UX'
-      output = %x{/bin/netstat -in | sed -e 1d}
+      # (#17487)[https://projects.puppetlabs.com/issues/17487]
+      # Handle NIC bonding where asterisks and virtual NICs are printed.
+      if output = hpux_netstat_in
+        output.gsub!(/\*/, "")                  # delete asterisks.
+        output.gsub!(/^[^\n]*none[^\n]*\n/, "") # delete lines with 'none' instead of IPs.
+        output.sub!(/^[^\n]*\n/, "")            # delete the header line.
+        output
+      end
     when 'windows'
       output = %x|#{ENV['SYSTEMROOT']}/system32/netsh.exe interface ip show interface|
       output += %x|#{ENV['SYSTEMROOT']}/system32/netsh.exe interface ipv6 show interface|
@@ -89,6 +96,29 @@ module Facter::Util::IP
     output
   end
 
+
+  ##
+  # exec_ifconfig uses the ifconfig command
+  #
+  # @return [String] the output of `ifconfig #{arguments} 2>/dev/null` or nil
+  def self.exec_ifconfig(additional_arguments=[])
+    Facter::Util::Resolution.exec("#{self.get_ifconfig} #{additional_arguments.join(' ')}")
+  end
+  ##
+  # get_ifconfig looks up the ifconfig binary
+  #
+  # @return [String] path to the ifconfig binary
+  def self.get_ifconfig
+    common_paths=["/bin/ifconfig","/sbin/ifconfig","/usr/sbin/ifconfig"]
+    common_paths.select{|path| File.executable?(path)}.first
+  end
+  ##
+  # hpux_netstat_in is a delegate method that allows us to stub netstat -in
+  # without stubbing exec.
+  def self.hpux_netstat_in
+    Facter::Util::Resolution.exec("/bin/netstat -in")
+  end
+
   def self.get_infiniband_macaddress(interface)
     if File.exists?("/sys/class/net/#{interface}/address") then
       ib_mac_address = `cat /sys/class/net/#{interface}/address`.chomp
@@ -103,7 +133,7 @@ module Facter::Util::IP
   end
 
   def self.ifconfig_interface(interface)
-    %x{/sbin/ifconfig #{interface} 2>/dev/null}
+    output = Facter::Util::IP.exec_ifconfig([interface,"2>/dev/null"])
   end
 
   def self.get_single_interface_output(interface)
@@ -120,17 +150,25 @@ module Facter::Util::IP
         output = ifconfig_output
       end
     when 'SunOS'
-      output = %x{/usr/sbin/ifconfig #{interface}}
+      output = Facter::Util::IP.exec_ifconfig([interface])
     when 'HP-UX'
        mac = ""
-       ifc = %x{/usr/sbin/ifconfig #{interface}}
-       %x{/usr/sbin/lanscan}.scan(/(\dx\S+).*UP\s+(\w+\d+)/).each {|i| mac = i[0] if i.include?(interface) }
+       ifc = hpux_ifconfig_interface(interface)
+       hpux_lanscan.scan(/(\dx\S+).*UP\s+(\w+\d+)/).each {|i| mac = i[0] if i.include?(interface) }
        mac = mac.sub(/0x(\S+)/,'\1').scan(/../).join(":")
        output = ifc + "\n" + mac
     end
     output
   end
 
+  def self.hpux_ifconfig_interface(interface)
+    Facter::Util::IP.exec_ifconfig([interface])
+  end
+
+  def self.hpux_lanscan
+    Facter::Util::Resolution.exec("/usr/sbin/lanscan")
+  end
+
   def self.get_output_for_interface_and_label(interface, label)
     return get_single_interface_output(interface) unless Facter.value(:kernel) == 'windows'
 
@@ -168,6 +206,19 @@ module Facter::Util::IP
     device
   end
 
+  ##
+  # get_interface_value obtains the value of a specific attribute of a specific
+  # interface.
+  #
+  # @param interface [String] the interface identifier, e.g. "eth0" or "bond0"
+  #
+  # @param label [String] the attribute of the interface to obtain a value for,
+  # e.g. "netmask" or "ipaddress"
+  #
+  # @api private
+  #
+  # @return [String] representing the requested value.  An empty array is
+  # returned if the kernel is not supported by the REGEX_MAP constant.
   def self.get_interface_value(interface, label)
     tmp1 = []
 
@@ -186,9 +237,11 @@ module Facter::Util::IP
     # We have to dig a bit to get the original/real MAC address of the interface.
     bonddev = get_bonding_master(interface)
     if label == 'macaddress' and bonddev
-      bondinfo = IO.readlines("/proc/net/bonding/#{bonddev}")
-      hwaddrre = /^Slave Interface: #{interface}\n[^\n].+?\nPermanent HW addr: (([0-9a-fA-F]{2}:?)*)$/m
-      value = hwaddrre.match(bondinfo.to_s)[1].upcase
+      bondinfo = read_proc_net_bonding("/proc/net/bonding/#{bonddev}")
+      re = /^Slave Interface: #{interface}\b.*?\bPermanent HW addr: (([0-9A-F]{2}:?)*)$/im
+      if match = re.match(bondinfo)
+        value = match[1].upcase
+      end
     else
       output_int = get_output_for_interface_and_label(interface, label)
 
@@ -208,6 +261,19 @@ module Facter::Util::IP
     end
   end
 
+  ##
+  # read_proc_net_bonding is a seam method for mocking purposes.
+  #
+  # @param path [String] representing the path to read, e.g. "/proc/net/bonding/bond0"
+  #
+  # @api private
+  #
+  # @return [String] modeling the raw file read
+  def self.read_proc_net_bonding(path)
+    File.read(path) if File.exists?(path)
+  end
+  private_class_method :read_proc_net_bonding
+
   def self.get_network_value(interface)
     require 'ipaddr'
 
