@@ -46,7 +46,7 @@ module Facter::Util::Virtual
 
   def self.vserver?
     return false unless FileTest.exists?("/proc/self/status")
-    txt = File.read("/proc/self/status")
+    txt = File.open("/proc/self/status", "rb").read
     return true if txt =~ /^(s_context|VxID):[[:blank:]]*[0-9]/
     return false
   end
