@@ -1,6 +1,7 @@
 #! /usr/bin/env ruby
 
 require 'spec_helper'
+require 'facter/util/ip'
 
 def ifconfig_fixture(filename)
   File.read(fixtures('ifconfig', filename))
@@ -17,7 +18,8 @@ describe "IPv6 address fact" do
 
   it "should return ipaddress6 information for Darwin" do
     Facter::Util::Resolution.stubs(:exec).with('uname -s').returns('Darwin')
-    Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a').
+    Facter::Util::IP.stubs(:get_ifconfig).returns("/sbin/ifconfig")
+    Facter::Util::IP.stubs(:exec_ifconfig).with(["-a"]).
       returns(ifconfig_fixture('darwin_ifconfig_all_with_multiple_interfaces'))
 
     Facter.value(:ipaddress6).should == "2610:10:20:209:223:32ff:fed5:ee34"
@@ -25,7 +27,8 @@ describe "IPv6 address fact" do
 
   it "should return ipaddress6 information for Linux" do
     Facter::Util::Resolution.stubs(:exec).with('uname -s').returns('Linux')
-    Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig 2>/dev/null').
+    Facter::Util::IP.stubs(:get_ifconfig).returns("/sbin/ifconfig")
+    Facter::Util::IP.stubs(:exec_ifconfig).with(["2>/dev/null"]).
       returns(ifconfig_fixture('linux_ifconfig_all_with_multiple_interfaces'))
 
     Facter.value(:ipaddress6).should == "2610:10:20:209:212:3fff:febe:2201"
@@ -33,7 +36,8 @@ describe "IPv6 address fact" do
 
   it "should return ipaddress6 information for Solaris" do
     Facter::Util::Resolution.stubs(:exec).with('uname -s').returns('SunOS')
-    Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/ifconfig -a').
+    Facter::Util::IP.stubs(:get_ifconfig).returns("/usr/sbin/ifconfig")
+    Facter::Util::IP.stubs(:exec_ifconfig).with(["-a"]).
       returns(ifconfig_fixture('sunos_ifconfig_all_with_multiple_interfaces'))
 
     Facter.value(:ipaddress6).should == "2610:10:20:209:203:baff:fe27:a7c"
